summaryrefslogtreecommitdiffstats
path: root/src/include/gpxe/socket.h
diff options
context:
space:
mode:
authorMichael Brown2007-05-26 22:41:23 +0200
committerMichael Brown2007-05-26 22:41:23 +0200
commita1210e4fcab0e8dbf696444da13552f612701198 (patch)
tree11fb537874eba3a7c38a2d40b2d17e77fe297c08 /src/include/gpxe/socket.h
parentAdded EPIPE description. (diff)
downloadipxe-a1210e4fcab0e8dbf696444da13552f612701198.tar.gz
ipxe-a1210e4fcab0e8dbf696444da13552f612701198.tar.xz
ipxe-a1210e4fcab0e8dbf696444da13552f612701198.zip
Eliminate PF_INET; just use the AF_INET from the struct sockaddr instead.
Diffstat (limited to 'src/include/gpxe/socket.h')
-rw-r--r--src/include/gpxe/socket.h51
1 files changed, 21 insertions, 30 deletions
diff --git a/src/include/gpxe/socket.h b/src/include/gpxe/socket.h
index ea602537..d47369aa 100644
--- a/src/include/gpxe/socket.h
+++ b/src/include/gpxe/socket.h
@@ -8,31 +8,7 @@
*/
/**
- * @defgroup commdomains Communication domains
- *
- * @{
- */
-#define PF_INET 1 /**< IPv4 Internet protocols */
-#define PF_INET6 2 /**< IPv6 Internet protocols */
-/** @} */
-
-/**
- * Name communication domain
- *
- * @v domain Communication domain (e.g. PF_INET)
- * @ret name Name of communication domain
- */
-static inline __attribute__ (( always_inline )) const char *
-socket_domain_name ( int domain ) {
- switch ( domain ) {
- case PF_INET: return "PF_INET";
- case PF_INET6: return "PF_INET6";
- default: return "PF_UNKNOWN";
- }
-}
-
-/**
- * @defgroup commtypes Communication types
+ * @defgroup commtypes Communication semantics
*
* @{
*/
@@ -41,14 +17,14 @@ socket_domain_name ( int domain ) {
/** @} */
/**
* Name communication type
*
* @v type Communication type (e.g. SOCK_STREAM)
* @ret name Name of communication type
*/
static inline __attribute__ (( always_inline )) const char *
-socket_type_name ( int type ) {
- switch ( type ) {
+socket_semantics_name ( int semantics ) {
+ switch ( semantics ) {
case SOCK_STREAM: return "SOCK_STREAM";
case SOCK_DGRAM: return "SOCK_DGRAM";
default: return "SOCK_UNKNOWN";
@@ -64,6 +40,21 @@ socket_type_name ( int type ) {
#define AF_INET6 2 /**< IPv6 Internet addresses */
/** @} */
+/**
+ * Name address family
+ *
+ * @v family Address family (e.g. AF_INET)
+ * @ret name Name of address family
+ */
+static inline __attribute__ (( always_inline )) const char *
+socket_family_name ( int family ) {
+ switch ( family ) {
+ case AF_INET: return "AF_INET";
+ case AF_INET6: return "AF_INET6";
+ default: return "AF_UNKNOWN";
+ }
+}
+
/** A socket address family */
typedef uint16_t sa_family_t;
@@ -41,14 +17,14 @@ socket_domain_name ( int domain ) {
/** @} */
/**
- * Name communication type
+ * Name communication semantics
*
@@ -41,14 +17,14 @@ socket_domain_name ( int domain ) {
*
- * @v type Communication type (e.g. SOCK_STREAM)
- * @ret name Name of communication type
+ * @v semantics Communication semantics (e.g. SOCK_STREAM)
+ * @ret name Name of communication semantics
*/
static inline __attribute__ (( always_inline )) const char *